# This Repo is created by [OK git][huik]
[![python version](https://img.shields.io/badge/python-3.5%20%7C%203.6%20%7C%203.7%20-blue)][pythonwebsite] 
[![Alt text](https://img.shields.io/pypi/v/huik-module 'Hover to see this text.')][huik]
### Emphasis
*Italic* ; **Bold** ; ***Bold and Italic*** ; ~~Scratch~~
### List items
1. First ordered list item
* Unordered list can use asterisks

[huik]:https://pypi.org/project/huik-module
[pythonwebsite]: https://www.python.org/downloads/release/python-375
